package com.schoolinout.system.service.impl;

import java.util.List;
import com.schoolinout.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.schoolinout.system.mapper.SchoolMapper;
import com.schoolinout.system.domain.School;
import com.schoolinout.system.service.ISchoolService;

/**
 * 学校管理Service业务层处理
 * 
 * @author sakura
 * @date 2024-01-03
 */
@Service
public class SchoolServiceImpl implements ISchoolService 
{
    @Autowired
    private SchoolMapper schoolMapper;

    /**
     * 查询学校管理
     * 
     * @param id 学校管理主键
     * @return 学校管理
     */
    @Override
    public School selectSchoolById(Long id)
    {
        return schoolMapper.selectSchoolById(id);
    }

    /**
     * 查询学校管理列表
     * 
     * @param school 学校管理
     * @return 学校管理
     */
    @Override
    public List<School> selectSchoolList(School school)
    {
        return schoolMapper.selectSchoolList(school);
    }

    /**
     * 新增学校管理
     * 
     * @param school 学校管理
     * @return 结果
     */
    @Override
    public int insertSchool(School school)
    {
        school.setCreateTime(DateUtils.getNowDate());
        return schoolMapper.insertSchool(school);
    }

    /**
     * 修改学校管理
     * 
     * @param school 学校管理
     * @return 结果
     */
    @Override
    public int updateSchool(School school)
    {
        school.setUpdateTime(DateUtils.getNowDate());
        return schoolMapper.updateSchool(school);
    }

    /**
     * 批量删除学校管理
     * 
     * @param ids 需要删除的学校管理主键
     * @return 结果
     */
    @Override
    public int deleteSchoolByIds(Long[] ids)
    {
        return schoolMapper.deleteSchoolByIds(ids);
    }

    /**
     * 删除学校管理信息
     * 
     * @param id 学校管理主键
     * @return 结果
     */
    @Override
    public int deleteSchoolById(Long id)
    {
        return schoolMapper.deleteSchoolById(id);
    }
}
